@@ -23,6 +23,9 @@
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 ///
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+BUILD::BUILD(DistMatrix* dist) : PAMInitializer(dist) {
+}
+
 std::vector<int> BUILD::run(const std::vector<int>& ids, int k)
 {
     int nn = (int) ids.size();
@@ -103,6 +106,11 @@ std::vector<int> BUILD::run(const std::vector<int>& ids, int k)
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 ///
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+LAB::LAB(DistMatrix* dist, int seed) : PAMInitializer(dist)
+{
+    random.SetSeed(seed);
+}
+
 // Partial Fisher-Yates shuffle.
 void LAB::shuffle(std::vector<int> &samples, int ssize, int end) {
     ssize = ssize < end ? ssize : end; // Guard for choosing from tiny sets
@@ -764,9 +772,9 @@ std::vector<int> PAMUtils::randomSample(Xoroshiro128Random& rand,
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 CLARA::CLARA(int num_obs, DistMatrix *dist_matrix, PAMInitializer* init, int k, int maxiter, int numsamples, double sampling, bool independent, int seed)
 :  num_obs(num_obs), dist_matrix(dist_matrix), initializer(init), k(k),
-maxiter(maxiter), sampling(sampling), numsamples(numsamples), keepmed(!independent), random(seed)
+maxiter(maxiter), sampling(sampling), numsamples(numsamples), keepmed(!independent)
 {
-    
+    random.SetSeed(seed);
 }
 
 CLARA::~CLARA() {
@@ -917,9 +925,9 @@ double FastCLARA::run()
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 CLARANS::CLARANS(int num_obs, DistMatrix *dist_matrix, int k, int numlocal, double maxneighbor, int seed)
 : num_obs(num_obs), dist_matrix(dist_matrix), k(k),
-numlocal(numlocal), maxneighbor(maxneighbor), random(seed)
+numlocal(numlocal), maxneighbor(maxneighbor)
 {
-    
+    random.SetSeed(seed);
 }
 
 CLARANS::~CLARANS() {
@@ -1344,4 +1352,3 @@ void FastAssignment::performLastSwap(int h)
         }
     }
 }
-
